import React, { Component } from 'react';
import { ToastAndroid } from 'react-native';
import {
  Container,
  Content,
  Footer,
  FooterTab,
  Left,
  Button,
  Icon,
  Fab,
  View,
  Text
} from 'native-base';
import {
  Col,
  Row,
  Grid
} from 'react-native-easy-grid'
import AppHeader from './../components/Header';
import Realm from 'realm';

let realm = new Realm({
  schema: [{
    name: 'Reminder',
    properties: {
      medName: 'string',
      reminderTime: 'date'
    }
  }]
})

class HomeScreen extends Component {
  constructor() {
    super();
    this.state = {
      active: false,
      today: this.formatDate(new Date(Date.now()))
    };
  }

  componentWillMount() {
    let myReminder = realm.objects('Reminder')
    ToastAndroid.show(JSON.stringify(myReminder), ToastAndroid.SHORT)
  }

  render() {

    var { containerStyle, timePeriodLeftStyle, timePeriodRightStyle, dateTitle } = styles;

    return (
      <Container style={{ backgroundColor: 'white' }}>
        <AppHeader
          headerText={'Pill Minder'}
          headerLeft={
            <Button onPress={this.onMenuPressed.bind(this)}>
              <Icon name='menu' />
            </Button>
          }
          headerRight={
            <Button onPress={this.onAddMedicinePressed.bind(this)}>
              <Icon name='add' />
            </Button>
          }
        />
        <Content style={{ flex: 1 }}>
          <Text style={dateTitle}>{this.state.today}</Text>
          <Grid>
            <Col>
              <Row>
                <View style={timePeriodLeftStyle}>
                  <Text>Morning</Text>
                  <View style={containerStyle}>

                  </View>
                </View>
              </Row>
              <Row>
                <View style={timePeriodLeftStyle}>
                  <Text>Afternoon</Text>
                  <View style={containerStyle}>

                  </View>
                </View>
              </Row>
            </Col>
            <Col>
              <Row>
                <View style={timePeriodRightStyle}>
                  <Text>Evening</Text>
                  <View style={containerStyle}>

                  </View>
                </View>
              </Row>
              <Row>
                <View style={timePeriodRightStyle}>
                  <Text>Night</Text>
                  <View style={containerStyle}>

                  </View>
                </View>
              </Row>
            </Col>
          </Grid>
        </Content>
      </Container >
    )

  }

  onHomePressed() {
    this.props.navigation.navigate('Home');
  }

  onCameraPressed() {
    this.props.navigation.navigate('Camera');
  }

  onAddMedicinePressed() {
    this.props.navigation.navigate('Medications')
  }

  onMenuPressed() {
    this.props.navigation.navigate('DrawerToggle');
  }

  formatDate(date) {
    var monthNames = [
      "January", "February", "March",
      "April", "May", "June", "July",
      "August", "September", "October",
      "November", "December"
    ];

    var day = date.getDate();
    var monthIndex = date.getMonth();

    return 'Today, ' + day + ' ' + monthNames[monthIndex];
  }

}

const styles = {
  containerStyle: {
    flex: 1,
    backgroundColor: 'white',
    borderWidth: 5,
    borderRadius: 2,
    borderColor: '#1686C4',
    borderBottomWidth: 0,
    elevation: 1,
    padding: 10
  },
  timePeriodLeftStyle: {
    flex: 1,
    height: 200,
    marginLeft: 20,
    marginRight: 10,
    marginTop: 20,
    marginBottom: 20
  },
  timePeriodRightStyle: {
    flex: 1,
    height: 200,
    marginLeft: 10,
    marginRight: 20,
    marginTop: 20,
    marginBottom: 20
  },
  dateTitle: {
    fontSize: 20,
    textAlign: 'center',
    marginTop: 20,
    marginLeft: 20,
    marginLeft: 20,
    marginBottom: 10,
  }
}

export default HomeScreen;